#version 330

#define BRIGHTNESS_FACTOR 1.0

in vec2 uvFrag;

uniform vec3 playerPosition;
uniform vec3 lightVector;

uniform sampler2D colorTextureDay;
uniform sampler2D colorTextureNight;

out vec4 fragColor;

void main() {
	
	// decisionVariable in [-1, +1]
	float decisionVariable = dot(normalize(playerPosition), normalize(lightVector));
	
	if (decisionVariable > 0.25) {

		// the background is Day
		vec3 colorDay = texture(colorTextureDay, uvFrag).rgb;
		fragColor = vec4(colorDay.x, colorDay.y, colorDay.z, 1.0);

	} else if (decisionVariable > -0.25) {

		// the background ist interpolated between Day and Night
		float a = (decisionVariable + 0.25) * 2.0;
		vec3 colorDay = texture(colorTextureDay, uvFrag).rgb;
		vec3 colorNight = texture(colorTextureNight, uvFrag).rgb;
		fragColor = vec4(colorDay.x, colorDay.y, colorDay.z, 1.0) * a + vec4(colorNight.x, colorNight.y, colorNight.z, 1.0) * (1.0 - a);

	} else {
	
		// the background is Night
		vec3 colorNight = texture(colorTextureNight, uvFrag).rgb;
		fragColor = vec4(colorNight.x, colorNight.y, colorNight.z, 1.0);

	}
	
	fragColor = fragColor * BRIGHTNESS_FACTOR;

}